# Reemote 

Reemote is a Python API for task automation, configuration management and application deployment.

Visit [reemote.org](http://reemote.org/).

# Example

The [GUI example](examples/gui) demonstrates a switch that creates or removes the directory `/tmp/mydir` on all the servers in an inventory.

![GUI Demo](examples/gui/gui_demo.png)

# Installation

Install from PyPI 

```bash
pip install reemote
```
